View Source ExFiskal.ZKI (ExFiskal v1.2.0)

Handles generation of ZKI (zaštitni kod izdavatelja) for Croatian fiscalization. The ZKI is a security code that confirms the link between the fiscalization obligor and the issued receipt.

Summary

Functions

generate!(params, certificate_data)